@@ -6,18 +6,21 @@ __copyright__ = "Copyright 2020, Microsoft Corp."
 
 from typing import Any
 
+
 class BonsaiClientError(Exception):
     """
     Generic wrapper for exceptions originating in client implementations
     """
+
     def __init__(self, msg: str, e: str):
         super(BonsaiClientError, self).__init__("{}: {}".format(msg, repr(e)))
         self.original_exception = e
 
+
 class AuthenticationError(BonsaiClientError):
     def __init__(self, e: Any):
-        super(AuthenticationError, self).__init__("Error authenticating user",
-                                                  e)
+        super(AuthenticationError, self).__init__("Error authenticating user", e)
+
 
 class RetryTimeoutError(Exception):
     pass
